# TimeOfDayCondition

A specific time frame condition, in hour/minute/second 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**hour** | **int** | the hour in the day, based in 24 hour clock, in UTC. | [optional] 
**minute** | **int** | the minute in the day, in UTC. | [optional] 
**second** | **int** | the second in the day, in UTC. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


